Base schema: http://purl.allotrope.org/json-schemas/adm/liquid-chromatography/REC/2023/09/liquid-chromatography.schema

Changes:

* Added pH-cube-detector measurementDocumentItems to liquid-chromatography measurement schemas
  * Reasoning: Extend support for pH chromatogram data within liquid-chromatography schema
  * Proposal: Added pH-cube-detector measurementDocumentItems to liquid-chromatography measurement schemas REC/2024/12
